<?php

class socketServer
{
	private $server;
	public $handle;
	
	public function __construct($host,$port) {
        $this->server = new swoole_websocket_server($host, $port);
		$this->server->set(array(
            'open_tcp_nodelay' => 1,
            'open_cpu_affinity' => 1,
            'task_worker_num' =>8,
            'dispatch_mode'=>2,
            'daemonize' => 0,//守护进程化。设置daemonize => 1时，程序将转入后台作为守护进程运行。长时间运行的服务器端程序必须启用此项。
            'reactor_num' => 2,//2个处理线程的数量
            'worker_num' => 4,//4个线程
            'max_request' => 0,//最大10万个连接请求
            // 'heartbeat_idle_time' => 60,//如果客户端超过600秒未向服务器发消息
            // 'heartbeat_check_interval' =>61,//每60秒检查一次所有的连接

			'log_file' => './swoole.log'
		));

        $this->server->on('start', array($this, 'onStart'));
        $this->server->on('shutdown', array($this, 'onShutdown'));
		
        $this->server->on('workerStart', array($this, 'onWorkerStart'));
        $this->server->on('workerStop', array($this, 'onWorkerStop'));
        $this->server->on('workerError', array($this, 'onWorkerError'));
		
        $this->server->on('open', array($this, 'onOpen'));
        $this->server->on('message', array($this, 'onMessage'));
		
        $this->server->on('request', array($this, 'onRequest'));
		
		$this->server->on('task', array($this, 'onTask'));
        $this->server->on('finish', array($this, 'onFinish'));
		
        $this->server->on('close', array($this, 'onClose'));
        $this->server->start();
    }
	
    //Server启动在主进程的主线程回调此函数
    public function onStart( $server ) {
        // cli_set_process_title("ws_server1");
    }

	//此事件在Server正常结束时发生
    public function onShutdown( $server ) {
        //$this->_echo_log(__CLASS__."->".__FUNCTION__."\r\n");
    }
	
	//此事件在Worker进程时发生（加载socket业务文件）
    public function onWorkerStart( $server , $worker_id) {
        require_once "./swoole/socketWork.php";
		$this->handle = new socketWork($server);
    }

	//此事件在worker进程终止时发生
    public function onWorkerStop( $server , $worker_id) {
		$this->handle->onWorkerStop($server, $worker_id);
    }   

	//当worker/task_worker进程发生异常后会在Manager进程内回调此函数
	public function onWorkerError( $server , $worker_id) {
		$this->handle->onWorkerError($server, $worker_id);
    }

	//websocket客户端链接回调
    public function onOpen( $server , $request) {
        $this->handle->onOpen($server, $request);
    }
	
	//websocket客户端发送消息回调
    public function onMessage( $server, $frame) {
		$this->handle->onMessage($server, $frame);
    }

	//http访问回调
    public function onRequest( $request, $response) {
		$this->handle->onRequest($this->server,$request, $response);
    }

	//在task_worker进程内被调用
	public function onTask($server,$task_Id, $worker_id, $data){
		$this->handle->onTask($server, $task_Id, $worker_id, $data);
    }

	//当worker进程投递的任务在task_worker中完成时
    public function onFinish($server,$task_Id, $data){
        $this->handle->onFinish($server,$task_Id, $data);
    }
	
	//客户端连接关闭
    public function onClose($server, $fd) {

		$this->handle->onClose($server, $fd);
    }
	
}